﻿using System.Reflection;
using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;

[assembly: AssemblyTitle("openBVE")]
[assembly: AssemblyProduct("openBVE")]
[assembly: AssemblyCopyright("(AntiCopyright) 2008-2010 openBVE Project")]
[assembly: ComVisible(false)]
[assembly: Guid("bd68500e-8db6-4394-8fec-6adcde64c213")]
[assembly: AssemblyVersion("1.2.7.3")]
[assembly: AssemblyFileVersion("1.2.7.3")]

namespace OpenBve {
	internal static partial class Program {
		internal const bool IsDevelopmentVersion = false;
	}
}